using System;
using System.Collections.Generic;

class Product
{
    public int ID { get; set; }
    public string Name { get; set; }
    public decimal Price { get; set; }
    public int StockQuantity { get; set; }

    public void DisplayInfo()
    {
        Console.WriteLine($"{ID}. {Name} - {Price:C} - {StockQuantity} in stock");
    }
}

class Customer
{
    public int ID { get; set; }
    public string Name { get; set; }
    public string Address { get; set; }
    public List<Product> PurchasedProducts { get; set; } = new List<Product>();

    public void PlaceOrder(Product product)
    {
        if (product.StockQuantity > 0)
        {
            PurchasedProducts.Add(product);
            product.StockQuantity--;
            Console.WriteLine($"Order placed successfully. Total amount: {product.Price:C}");
        }
        else
        {
            Console.WriteLine("Product out of stock.");
        }
    }
}

class Order
{
    public int ID { get; set; }
    public DateTime OrderDate { get; set; }
    public Customer Customer { get; set; }
    public List<Product> OrderedProducts { get; set; } = new List<Product>();
}

class OnlineStore
{
    public List<Product> Products { get; set; } = new List<Product>();
    public List<Customer> Customers { get; set; } = new List<Customer>();
    public List<Order> Orders { get; set; } = new List<Order>();

    public void DisplayProductList()
    {
        Console.WriteLine("Available products:");
        foreach (Product product in Products)
        {
            product.DisplayInfo();
        }
    }

    public void DisplayCustomerPurchasedProducts(Customer customer)
    {
        Console.WriteLine("Customer's Purchased Products:");
        foreach (Product purchasedProduct in customer.PurchasedProducts)
        {
            Console.WriteLine(purchasedProduct.Name);
        }
    }
}

class Program
{
    static void Main()
    {
        OnlineStore myStore = new OnlineStore();

        Console.WriteLine("Enter product information for Laptop (ID Name Price StockQuantity):");
        string[] laptopInfo = Console.ReadLine().Split();
        Product laptop = new Product { ID = int.Parse(laptopInfo[0]), Name = laptopInfo[1], Price = decimal.Parse(laptopInfo[2]), StockQuantity = int.Parse(laptopInfo[3]) };
        myStore.Products.Add(laptop);

        Console.WriteLine("Enter product information for Smartphone (ID Name Price StockQuantity):");
        string[] smartphoneInfo = Console.ReadLine().Split();
        Product smartphone = new Product { ID = int.Parse(smartphoneInfo[0]), Name = smartphoneInfo[1], Price = decimal.Parse(smartphoneInfo[2]), StockQuantity = int.Parse(smartphoneInfo[3]) };
        myStore.Products.Add(smartphone);

        Console.WriteLine("Enter customer name:");
        string customerName = Console.ReadLine();
        Console.WriteLine("Enter customer address:");
        string customerAddress = Console.ReadLine();
        Customer customer = new Customer { ID = 1, Name = customerName, Address = customerAddress };
        myStore.Customers.Add(customer);

        myStore.DisplayProductList();

        Console.WriteLine("Enter the product ID you want to order:");
        int selectedProductID = int.Parse(Console.ReadLine());

        Product selectedProduct = myStore.Products.Find(p => p.ID == selectedProductID);

        if (selectedProduct != null)
        {
            customer.PlaceOrder(selectedProduct);
            myStore.DisplayCustomerPurchasedProducts(customer);
        }
        else
        {
            Console.WriteLine("Invalid product ID.");
        }
    }
}
