using System;
using System.Collections.Generic;

class Course
{
    private string title;
    private int duration;
    private decimal price;

    public Course(string title, int duration, decimal price)
    {
        Title = title;
        Duration = duration;
        Price = price;
    }

    public string Title
    {
        get { return title; }
        set
        {
            if (string.IsNullOrWhiteSpace(value))
            {
                throw new ArgumentException("Invalid course title!");
            }
            title = value;
        }
    }

    public int Duration
    {
        get { return duration; }
        set
        {
            if (value <= 0)
            {
                throw new ArgumentException("Duration must be a positive number!");
            }
            duration = value;
        }
    }

    public decimal Price
    {
        get { return price; }
        set
        {
            if (value <= 0)
            {
                throw new ArgumentException("Price must be a positive number!");
            }
            price = value;
        }
    }
}

class Student
{
    private string name;
    private List<Course> courses;

    public Student(string name)
    {
        Name = name;
        courses = new List<Course>();
    }

    public string Name
    {
        get { return name; }
        set
        {
            if (string.IsNullOrWhiteSpace(value))
            {
                throw new ArgumentException("Invalid student name!");
            }
            name = value;
        }
    }

    public List<Course> Courses { get { return courses; } }

    public void Enroll(Course course)
    {
        courses.Add(course);
    }
}

class University
{
    private List<Course> courses;
    private List<Student> students;

    public University()
    {
        courses = new List<Course>();
        students = new List<Student>();
    }

    public List<Course> Courses { get { return courses; } }
    public List<Student> Students { get { return students; } }

    public void AddCourse(Course course)
    {
        courses.Add(course);
    }

    public void RegisterStudent(Student student)
    {
        students.Add(student);
    }

    public void DisplayCourses()
    {
        Console.WriteLine("All Courses:");
        foreach (var course in courses)
        {
            Console.WriteLine($"Title: {course.Title}, Duration: {course.Duration} hours, Price: {course.Price:C}");
        }
    }

    public void DisplayStudents()
    {
        Console.WriteLine("All Students:");
        foreach (var student in students)
        {
            Console.WriteLine($"Name: {student.Name}");
            Console.WriteLine("Enrolled Courses:");
            foreach (var course in student.Courses)
            {
                Console.WriteLine($"- {course.Title}");
            }
        }
    }
}

class Program
{
    static void Main()
    {
        University university = new University();

        // Adding courses
        university.AddCourse(new Course("Java Programming", 40, 150));
        university.AddCourse(new Course("Web Development", 30, 120));

        // Registering students
        Student student1 = new Student("Todor");
        student1.Enroll(university.Courses[0]);
        student1.Enroll(university.Courses[1]);

        Student student2 = new Student("Ivan");
        student2.Enroll(university.Courses[1]);

        university.RegisterStudent(student1);
        university.RegisterStudent(student2);

        // Displaying information about courses and students
        university.DisplayCourses();
        university.DisplayStudents();
    }
}
