import java.util.ArrayList;
import java.util.List;

class Course {
    private String title;
    private int duration;
    private double price;

    public Course(String title, int duration, double price) {
        setTitle(title);
        setDuration(duration);
        setPrice(price);
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        if (title == null || title.trim().isEmpty()) {
            throw new IllegalArgumentException("Invalid course title!");
        }
        this.title = title;
    }

    public int getDuration() {
        return duration;
    }

    public void setDuration(int duration) {
        if (duration <= 0) {
            throw new IllegalArgumentException("Duration must be a positive number!");
        }
        this.duration = duration;
    }

    public double getPrice() {
        return price;
    }

    public void setPrice(double price) {
        if (price <= 0) {
            throw new IllegalArgumentException("Price must be a positive number!");
        }
        this.price = price;
    }
}

class Student {
    private String name;
    private List<Course> courses;

    public Student(String name) {
        setName(name);
        courses = new ArrayList<>();
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        if (name == null || name.trim().isEmpty()) {
            throw new IllegalArgumentException("Invalid student name!");
        }
        this.name = name;
    }

    public List<Course> getCourses() {
        return courses;
    }

    public void enroll(Course course) {
        courses.add(course);
    }
}

class University {
    private List<Course> courses;
    private List<Student> students;

    public University() {
        courses = new ArrayList<>();
        students = new ArrayList<>();
    }

    public List<Course> getCourses() {
        return courses;
    }

    public List<Student> getStudents() {
        return students;
    }

    public void addCourse(Course course) {
        courses.add(course);
    }

    public void registerStudent(Student student) {
        students.add(student);
    }

    public void displayCourses() {
        System.out.println("All Courses:");
        for (Course course : courses) {
            System.out.printf("Title: %s, Duration: %d hours, Price: %.2f%n",
                    course.getTitle(), course.getDuration(), course.getPrice());
        }
    }

    public void displayStudents() {
        System.out.println("All Students:");
        for (Student student : students) {
            System.out.println("Name: " + student.getName());
            System.out.println("Enrolled Courses:");
            for (Course course : student.getCourses()) {
                System.out.println("- " + course.getTitle());
            }
        }
    }
}

class Main {
    public static void main(String[] args) {
        University university = new University();

        // Adding courses
        university.addCourse(new Course("Java Programming", 40, 150.0));
        university.addCourse(new Course("Web Development", 30, 120.0));

        // Registering students
        Student student1 = new Student("Todor");
        student1.enroll(university.getCourses().get(0));
        student1.enroll(university.getCourses().get(1));

        Student student2 = new Student("Ivan");
        student2.enroll(university.getCourses().get(1));

        university.registerStudent(student1);
        university.registerStudent(student2);

        // Displaying information about courses and students
        university.displayCourses();
        university.displayStudents();
    }
}
